@@ -1,7 +1,7 @@
 package Mojolicious::Plugin::AutoRoute;
 use Mojo::Base 'Mojolicious::Plugin';
 
-our $VERSION = '0.11';
+our $VERSION = '0.12';
 
 sub register {
   my ($self, $app, $conf) = @_;
@@ -40,7 +40,11 @@ sub register {
   # Index
   $r->route('/')
     ->over($condition_name)
-    ->to(cb => sub { shift->render("/$top_dir/index", 'mojo.maybe' => 1) });
+    ->to(cb => sub {
+      my $self = shift;
+      $self->render("/$top_dir/index", 'mojo.maybe' => 1);
+      $self->stash('mojo.finished') ? undef : $self->render_not_found;
+    });
   
   # Route
   $r->route('/(*__auto_route_plugin_path)')
@@ -52,16 +56,12 @@ sub register {
       $path =~ s/\/+$//;
       
       $c->render("/$top_dir/$path", 'mojo.maybe' => 1);
+      $c->stash('mojo.finished') ? undef : $c->render_not_found;
     });
   
   # Finish rendering Helper
   $app->helper(finish_rendering => sub {
-    my $self = shift;
-    
-    $self->stash->{'mojo.routed'} = 1;
-    $self->rendered;
-    
-    return $self;
+    warn "finish_rendering is DEPRECATED. no more needed";
   });
 }
 
@@ -73,7 +73,7 @@ Mojolicious::Plugin::AutoRoute - Mojolicious Plugin to create routes automatical
 
 =head1 CAUTION
 
-B<This is beta release and very experimental. Implementation will be changed without warnings>. 
+B<This is beta release and very experimental. Implementation will be changed without warnings>.
 
 =head1 SYNOPSIS
 
@@ -124,7 +124,6 @@ You only put file into C<auto> directory.
   @@ auto/json.html.ep
   <%
     $self->render(json => {foo => 1});
-    $self->finish_rendering;
     return;
   %>
   
@@ -147,33 +146,6 @@ Default is C<$app->routes>.
 
 Top directory. default is C<auto>.
 
-=head1 HELPER
-
-=head2 finish_rendering
-
-You can render data, json, not found and exeption from template
-using C<finish_rendering> helper.
-
-  @@ index.html.ep
-  $self->render(data => 'foo');
-  $self->finish_rendering;
-  return;
-
-  @@ index.html.ep
-  $self->render(json => {foo => 1});
-  $self->finish_rendering;
-  return;
-
-  @@ index.html.ep
-  $self->render_not_found;
-  $self->finish_rendering;
-  return;
-
-  @@ index.html.ep
-  $self->render_exception;
-  $self->finish_rendering;
-  return;
-
 =head1 FUNCTIONS
 
 =head2 template(Mojolicious::Plugin::AutoRoute::Util)
@@ -183,10 +155,10 @@ If you want to create custom route, use C<template> function.
   use Mojolicious::Plugin::AutoRoute::Util 'template';
   
   # Mojolicious Lite
-  get '/foo' => template '/foo';
+  any '/foo' => template 'foo';
 
   # Mojolicious
-  $r->get('/foo' => template '/foo');
+  $r->any('/foo' => template 'foo');
 
 C<template> is return callback to call C<render_maybe>.
 
